# Generated by roxygen2: do not edit by hand

export(sm_delete_job)
export(sm_diarize_channel)
export(sm_diarize_speaker)
export(sm_get_transcript)
export(sm_list_jobs)
export(sm_transcribe)
export(sm_transcription_config)
importFrom(rlang,"%||%")
