% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/transcribe.R
\name{sm_delete_job}
\alias{sm_delete_job}
\title{Delete a job}
\usage{
sm_delete_job(job_id)
}
\arguments{
\item{job_id}{Job ID string.}
}
\value{
\code{TRUE}, invisibly.
}
\description{
Delete a job
}
\examples{
\dontrun{
sm_delete_job("2om9psu1np")
}
}
