% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/transcribe.R
\name{sm_list_jobs}
\alias{sm_list_jobs}
\title{List all jobs}
\usage{
sm_list_jobs()
}
\value{
A data frame of jobs.
}
\description{
List all jobs
}
\examples{
\dontrun{
sm_list_jobs()
}
}
