% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/config.R
\name{sm_diarize_channel}
\alias{sm_diarize_channel}
\title{Configure channel diarization}
\usage{
sm_diarize_channel(labels = NULL)
}
\arguments{
\item{labels}{Character vector of channel labels (e.g. \code{c("Agent", "Caller")}).}
}
\value{
A diarization config list.
}
\description{
Configure channel diarization
}
\examples{
sm_diarize_channel()

# label channels
sm_diarize_channel(labels = c("Nic", "Jess"))
}
