% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/speechmatics-package.R
\docType{package}
\name{speechmatics-package}
\alias{speechmatics}
\alias{speechmatics-package}
\title{speechmatics: Client for the 'Speechmatics' Speech-to-Text API}
\description{
Transcribe audio files using the 'Speechmatics' speech-to-text API \url{https://www.speechmatics.com/}. Supports custom vocabulary, speaker diarization, punctuation control, and audio filtering.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/thisisnic/speechmatics}
  \item \url{https://thisisnic.github.io/speechmatics/}
  \item Report bugs at \url{https://github.com/thisisnic/speechmatics/issues}
}

}
\author{
\strong{Maintainer}: Nic Crane \email{thisisnic@gmail.com} [copyright holder]

Authors:
\itemize{
  \item Nic Crane \email{thisisnic@gmail.com} [copyright holder]
}

}
\keyword{internal}
